@@ -6,11 +6,13 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
 
 use Log::Log4perl ':easy';
 use SOAP::Lite;
 
+use WWW::SFDC::Apex::ExecuteAnonymousResult;
+
 use Moo;
 with "WWW::SFDC::Role::SessionConsumer";
 
@@ -56,21 +58,23 @@ sub compileTriggers {
 
 sub executeAnonymous {
   my ($self, $code, %options) = @_;
+
   my ($result, $headers) = $self->_call(
     'executeAnonymous',
     SOAP::Data->name(string => $code),
-    $options{debug} ? SOAP::Header->name('DebuggingHeader' => \SOAP::Data->name(
-        debugLevel => 'DEBUGONLY'
-      ))->uri($self->uri) : (),
-   );
+    (
+      $options{debug}
+        ? SOAP::Header->name('DebuggingHeader' => \SOAP::Data->name(
+            debugLevel => 'DEBUGONLY'
+          ))->uri($self->uri)
+        : ()
+    ),
+  );
 
-  LOGDIE "ExecuteAnonymous failed to compile: " . $result->{compileProblem}
-    if $result->{compiled} eq "false";
-
-  LOGDIE "ExecuteAnonymous failed to complete: " . $result->{exceptionMessage}
-    if ($result->{success} eq "false");
-
-  return $result, (defined $headers ? $headers->{debugLog} : ());
+  return WWW::SFDC::Apex::ExecuteAnonymousResult->new(
+    _result => $result,
+    _headers => $headers
+  );
 }
 
 
@@ -100,7 +104,7 @@ WWW::SFDC::Apex - Interface to the salesforce.com Apex SOAP Api
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 METHODS
 
@@ -112,6 +116,9 @@ version 0.32
 
 =head2 executeAnonymous
 
+Returns a WWW::SFDC::Apex::ExecuteAnonymousResult containing the results of the
+executeAnonymous call. You must manually check whether this succeeded.
+
 =head2 runTests
 
 =head2 wsdlToApex
