@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
 
 use Data::Dumper;
 use Log::Log4perl ':easy';
@@ -197,7 +197,7 @@ WWW::SFDC::Metadata - Interface to the Salesforce.com Metadata API
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -251,6 +251,9 @@ Takes a base64 zip file and deploys it. Deploy options will be
 passed verbatim into the request; see the metadata developer
 guide for a description.
 
+Returns a WWW::SFDC::Metadata::DeployResult containing the result of the
+operation. You must manually check whether this succeeded!
+
 =head2 deployRecentValidation $id
 
 Calls deployRecentValidation with your successfully-validated deployment.
